@@ -76,6 +76,7 @@ use File::Glob qw(:case);
     'sadahiro'	=> 'SADAHIRO Tomoyuki <SADAHIRO@cpan.org>',
     'salva'	=> 'Salvador Fandio Garca <salva@cpan.org>',
     'saper'	=> 'Sbastien Aperghis-Tramoni <saper@cpan.org>',
+    'sbeck'     => 'Sullivan Beck <sbeck@cpan.org>',
     'sburke'	=> 'Sean Burke <sburke@cpan.org>',
     'mschwern'	=> 'Michael Schwern <mschwern@cpan.org>',
     'simonw'	=> 'Simon Wistow <simonw@cpan.org>',
@@ -186,7 +187,7 @@ use File::Glob qw(:case);
     'Archive::Extract' =>
 	{
 	'MAINTAINER'	=> 'kane',
-	'DISTRIBUTION'	=> 'BINGOS/Archive-Extract-0.36.tar.gz',
+	'DISTRIBUTION'	=> 'BINGOS/Archive-Extract-0.38.tar.gz',
 	'FILES'		=> q[cpan/Archive-Extract],
 	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'cpan',
@@ -261,7 +262,7 @@ use File::Glob qw(:case);
     'B::Debug' =>
 	{
 	'MAINTAINER'	=> 'rurban',
-	'DISTRIBUTION'	=> 'RURBAN/B-Debug-1.11.tar.gz',
+	'DISTRIBUTION'	=> 'RURBAN/B-Debug-1.12.tar.gz',
 	'FILES'		=> q[cpan/B-Debug],
 	'EXCLUDED'	=> [ qw( t/coverage.html t/pod.t ) ],
 	'CPAN'		=> 1,
@@ -308,7 +309,7 @@ use File::Glob qw(:case);
     'CGI' =>
 	{
 	'MAINTAINER'	=> 'lstein',
-	'DISTRIBUTION'	=> 'LDS/CGI.pm-3.48.tar.gz',
+	'DISTRIBUTION'	=> 'LDS/CGI.pm-3.49.tar.gz',
 	'FILES'		=> q[cpan/CGI],
 	'EXCLUDED'	=> [ qr{^t/lib/Test},
 				qw( cgi-lib_porting.html
@@ -379,13 +380,14 @@ use File::Glob qw(:case);
     'CPAN' =>
 	{
 	'MAINTAINER'	=> 'andk',
-	'DISTRIBUTION'	=> 'ANDK/CPAN-1.94_53.tar.gz',
+	'DISTRIBUTION'	=> 'ANDK/CPAN-1.94_56.tar.gz',
 	'FILES'		=> q[cpan/CPAN],
 	'EXCLUDED'	=> [ qr{^distroprefs/},
 			     qr{^inc/Test/},
 			     qr{^t/CPAN/authors/},
 			     qw{
 				lib/CPAN/Admin.pm
+				Makefile.PL
 				SlayMakefile
 				t/00signature.t
 				t/04clean_load.t
@@ -443,7 +445,7 @@ use File::Glob qw(:case);
     'CPANPLUS::Dist::Build' =>
 	{
 	'MAINTAINER'	=> 'bingos',
-	'DISTRIBUTION'	=> 'BINGOS/CPANPLUS-Dist-Build-0.44.tar.gz',
+	'DISTRIBUTION'	=> 'BINGOS/CPANPLUS-Dist-Build-0.46.tar.gz',
 	'FILES'		=> q[cpan/CPANPLUS-Dist-Build],
 	'EXCLUDED'	=> [ qr{^inc/},
 			     qw{ t/99_pod.t
@@ -660,7 +662,7 @@ use File::Glob qw(:case);
     'File::Fetch' =>
 	{
 	'MAINTAINER'	=> 'kane',
-	'DISTRIBUTION'	=> 'BINGOS/File-Fetch-0.22.tar.gz',
+	'DISTRIBUTION'	=> 'BINGOS/File-Fetch-0.24.tar.gz',
 	'FILES'		=> q[cpan/File-Fetch],
 	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'cpan',
@@ -850,11 +852,11 @@ use File::Glob qw(:case);
 
     'Locale-Codes' =>
 	{
-	'MAINTAINER'	=> 'neilb',
+	'MAINTAINER'	=> 'sbeck',
 	'DISTRIBUTION'	=> 'NEILB/Locale-Codes-2.07.tar.gz',
 	'FILES'		=> q[cpan/Locale-Codes],
 	'CPAN'		=> 1,
-	'UPSTREAM'	=> undef,
+	'UPSTREAM'	=> 'cpan',
 	},
 
     'Locale::Maketext' =>
@@ -1004,7 +1006,7 @@ use File::Glob qw(:case);
     'Module::Build' =>
 	{
 	'MAINTAINER'	=> 'kwilliams',
-	'DISTRIBUTION'	=> 'DAGOLDEN/Module-Build-0.36.tar.gz',
+	'DISTRIBUTION'	=> 'DAGOLDEN/Module-Build-0.3603.tar.gz',
 	'FILES'		=> q[cpan/Module-Build],
 	'EXCLUDED'	=> [ qw{ t/par.t t/signature.t },
 			     qr!^contrib/!,  qr!^devtools! ],
@@ -1281,7 +1283,7 @@ use File::Glob qw(:case);
 
     'Pod::Plainer' =>
 	{
-	'DISTRIBUTION'	=> 'RMBARKER/Pod-Plainer-1.01.tar.gz',
+	'DISTRIBUTION'	=> 'RMBARKER/Pod-Plainer-1.02.tar.gz',
 	'MAINTAINER'	=> 'rmbarker',
 	'FILES'		=> q[dist/Pod-Plainer],
 	'CPAN'		=> 1,
@@ -1307,7 +1309,7 @@ use File::Glob qw(:case);
     'podlators' =>
 	{
 	'MAINTAINER'	=> 'rra',
-	'DISTRIBUTION'	=> 'RRA/podlators-2.2.2.tar.gz',
+	'DISTRIBUTION'	=> 'RRA/podlators-2.3.1.tar.gz',
 	'FILES'		=> q[cpan/podlators
 			     pod/pod2man.PL
 			     pod/pod2text.PL
@@ -1322,7 +1324,7 @@ use File::Glob qw(:case);
     'Safe' =>
 	{
 	'MAINTAINER'	=> 'rgarcia',
-	'DISTRIBUTION'	=> 'RGARCIA/Safe-2.19.tar.gz',
+	'DISTRIBUTION'	=> 'RGARCIA/Safe-2.22.tar.gz',
 	'FILES'		=> q[dist/Safe],
 	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'blead',
